#include "Countdown.h"
#include "Arduino.h"

#define U_LONG_MAX 0xFFFFFFFF

CountdownTimer::CountdownTimer(unsigned long ms) {
  if (!ms) {
    finish();
  } else {
    _atZero = false;
    _running = false;
    _remaining = ms;
  }
}

void CountdownTimer::start() {
  if (_running || _atZero) return;

  _endTime = millis() + _remaining;
  _running = true;
  _atZero = false;
}

void CountdownTimer::stop() {
  if (!_running) return;
  update();
  _running = false;
}

void CountdownTimer::finish() {
  _running = false;
  _atZero = true;
  _remaining = 0;
}


void CountdownTimer::add(unsigned long ms) { // Overflow unsafe
  if (!ms) return;
  if (_running) _endTime += ms;
  else _remaining += ms;

  _atZero = false;
}

void CountdownTimer::substract(unsigned long ms) {
  if (!ms || _atZero) return;
  if (_running) {
    if (_endTime < ms) finish(); // Prevents an underflow
    else _endTime -= ms;
  }
  else {
    if (_remaining < ms) finish(); // Prevents an underflow
    else _remaining -= ms;
  }
}

void CountdownTimer::set(unsigned long ms) {
  if (!ms) {finish(); return;}
  if (_running) _endTime = millis() + ms;
  else _remaining = ms;
  _atZero = false;
}

bool CountdownTimer::isPaused() {
  update();
  return !_running;
}

bool CountdownTimer::finished() {
  update();
  return _atZero;
}

unsigned long CountdownTimer::remaining() {
  update();
  return _remaining;
}

void CountdownTimer::update() {
  if (!_atZero && _running) {
    unsigned long cTime = millis();
    if (cTime < _endTime) _remaining = _endTime - cTime;
    else finish();
  }
}

