/* Keeps the built-in LED on the amount of time specified by the serial port,
 * with the possibility to add more time, and check the remaining on the fly.
 * 
 * The input format goes like this:
 * [single letter command][number]
 * 
 * Example: s5, a120 (no whitespaces in between)
 *
 * By Lucario448
 */


#include <Countdown.h>

CountdownTimer timer(0); // Create an already finished timer. This way, the LED starts off.

void setup() {
  Serial.begin(9600);
  while (!Serial); // Leonardo/Micro needed
  pinMode(13, OUTPUT);
}

void loop() {
  if (Serial.available()) {
    int in;
    switch (Serial.read()) {
      case 's':
      case 'S': // If command is "set"
      in = Serial.parseInt();
      if (in > 0) {
        timer.set(in * 1000);
        Serial.print(F("Timer has been set to "));
        Serial.print(in);
        Serial.print(F(" seconds."));
        timer.start();
      } else Serial.println(F("Invalid number input."));
      break;

      case 'a':
      case 'A': // If command is "add"
      in = Serial.parseInt();
      if (in > 0) {
        timer.add(in * 1000);
        Serial.print(in);
        Serial.println(F(" seconds have been added."));
        timer.start();
      } else Serial.println(F("Invalid number input."));;
      break;

      case 'c':
      case 'C': // If command is "check", it only requires the letter
      if (!timer.finished()) {
      Serial.print((timer.remaining() / 1000) + 1);
      Serial.println(F(" seconds before LED turns off."));
      } else Serial.println(F("Time is over."));
      break;

      default: Serial.println(F("Invalid command."));
    }
    Serial.flush(); // Discards any leftover from the serial buffer, to avoid false triggers.
  }
  
  digitalWrite(13, !timer.finished()); // Turns on only if the timer is running
}
