#include <Countdown.h>

#define INCREMENT 1000 // How much time to add to the timer (milliseconds) whenever the respective button is pressed

// Button-to-pin mapping
#define BUTTON_1 2
#define BUTTON_2 3
#define BUTTON_3 4
#define START_BUTTON 6

// Initial timers' values.
CountdownTimer t1(100000);
CountdownTimer t2(50000);
CountdownTimer t3(25000);

void setup() {
  pinMode(BUTTON_1, INPUT_PULLUP);
  pinMode(BUTTON_2, INPUT_PULLUP);
  pinMode(BUTTON_3, INPUT_PULLUP);
  pinMode(START_BUTTON, INPUT_PULLUP);
  // INPUT_PULLUP saves you some external resistors, but it must pull the pin to ground instead to voltage
  // Whenever a pin is pulled to ground, a button push is detected.
  
  Serial.begin(9600);
  startAll();
}

void loop() {
  // Shows us how much time is left for every timer (milliseconds).
  Serial.print(t1.remaining());
  Serial.write('\t');
  Serial.print(t2.remaining());
  Serial.write('\t');
  Serial.println(t3.remaining());

  if (!digitalRead(BUTTON_1)) t1.add(INCREMENT);
  if (!digitalRead(BUTTON_2)) t2.add(INCREMENT);
  if (!digitalRead(BUTTON_3)) t3.add(INCREMENT);
  if (!digitalRead(START_BUTTON)) startAll(); // If this button is pressed, any stopped timer will restart again (if not at zero).
  delay(100);
}

void startAll() {
  t1.start();
  t2.start();
  t3.start();
}

